@@ -2,29 +2,103 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Set of functions used to run cookie based authentication.
- * Thanks to Piotr Roszatycki <d3xter at users.sourceforge.net> and
- * Dan Wilson who built this patch for the Debian package.
  *
- * @version $Id: cookie.auth.lib.php 11326 2008-06-17 21:32:48Z lem9 $
+ * @package phpMyAdmin-Auth-Cookie
  */
 
 if (! defined('PHPMYADMIN')) {
     exit;
 }
 
-if (function_exists('mcrypt_encrypt') || PMA_dl('mcrypt')) {
+/**
+ * Swekey authentication functions.
+ */
+require './libraries/auth/swekey/swekey.auth.lib.php';
+
+if (function_exists('mcrypt_encrypt')) {
     /**
      * Uses faster mcrypt library if available
+     * (as this is not called from anywhere else, put the code in-line
+     *  for faster execution)
      */
-    require_once './libraries/mcrypt.lib.php';
+
+    /**
+     * Initialization
+     * Store the initialization vector because it will be needed for
+     * further decryption. I don't think necessary to have one iv
+     * per server so I don't put the server number in the cookie name.
+     */
+    if (empty($_COOKIE['pma_mcrypt_iv'])
+     || false === ($iv = base64_decode($_COOKIE['pma_mcrypt_iv'], true))) {
+        srand((double) microtime() * 1000000);
+         $td = mcrypt_module_open(MCRYPT_BLOWFISH, '', MCRYPT_MODE_CBC, '');
+         if ($td === false) {
+            PMA_warnMissingExtension('mcrypt');
+         }
+        $iv = mcrypt_create_iv(mcrypt_enc_get_iv_size($td), MCRYPT_RAND);
+        $GLOBALS['PMA_Config']->setCookie('pma_mcrypt_iv', base64_encode($iv));
+    }
+
+    /**
+     * Encryption using blowfish algorithm (mcrypt)
+     *
+     * @param   string  original data
+     * @param   string  the secret
+     *
+     * @return  string  the encrypted result
+     *
+     * @access  public
+     *
+     */
+    function PMA_blowfish_encrypt($data, $secret)
+    {
+        global $iv;
+        return base64_encode(mcrypt_encrypt(MCRYPT_BLOWFISH, $secret, $data, MCRYPT_MODE_CBC, $iv));
+    }
+
+    /**
+     * Decryption using blowfish algorithm (mcrypt)
+     *
+     * @param   string  encrypted data
+     * @param   string  the secret
+     *
+     * @return  string  original data
+     *
+     * @access  public
+     *
+     */
+    function PMA_blowfish_decrypt($encdata, $secret)
+    {
+        global $iv;
+        return trim(mcrypt_decrypt(MCRYPT_BLOWFISH, $secret, base64_decode($encdata), MCRYPT_MODE_CBC, $iv));
+    }
+
 } else {
     require_once './libraries/blowfish.php';
-    /**
-     * display warning in main.php
-     */
-    define('PMA_WARN_FOR_MCRYPT', 1);
+    if (!$GLOBALS['cfg']['McryptDisableWarning']) {
+        PMA_warnMissingExtension('mcrypt');
+    }
 }
 
+/**
+ * Returns blowfish secret or generates one if needed.
+ * @uses    $cfg['blowfish_secret']
+ * @uses    $_SESSION['auto_blowfish_secret']
+ *
+ * @access  public
+ */
+function PMA_get_blowfish_secret() {
+    if (empty($GLOBALS['cfg']['blowfish_secret'])) {
+        if (empty($_SESSION['auto_blowfish_secret'])) {
+            // this returns 23 characters
+            $_SESSION['auto_blowfish_secret'] = uniqid('', true);
+        }
+        return $_SESSION['auto_blowfish_secret'];
+    } else {
+        // apply md5() to work around too long secrets (returns 32 characters)
+        return md5($GLOBALS['cfg']['blowfish_secret']);
+    }
+}
 
 /**
  * Displays authentication form
@@ -40,20 +114,6 @@ if (function_exists('mcrypt_encrypt') || PMA_dl('mcrypt')) {
  * @uses    $GLOBALS['target']
  * @uses    $GLOBALS['db']
  * @uses    $GLOBALS['table']
- * @uses    $GLOBALS['PMA_errors']
- * @uses    $GLOBALS['convcharset']
- * @uses    $GLOBALS['lang']
- * @uses    $GLOBALS['strWelcome']
- * @uses    $GLOBALS['strSecretRequired']
- * @uses    $GLOBALS['strError']
- * @uses    $GLOBALS['strLogin']
- * @uses    $GLOBALS['strLogServer']
- * @uses    $GLOBALS['strLogUsername']
- * @uses    $GLOBALS['strLogPassword']
- * @uses    $GLOBALS['strServerChoice']
- * @uses    $GLOBALS['strGo']
- * @uses    $GLOBALS['strCookiesRequired']
- * @uses    $GLOBALS['strPmaDocumentation']
  * @uses    $GLOBALS['pmaThemeImage']
  * @uses    $cfg['Servers']
  * @uses    $cfg['LoginCookieRecall']
@@ -67,7 +127,6 @@ if (function_exists('mcrypt_encrypt') || PMA_dl('mcrypt')) {
  * @uses    PMA_sendHeaderLocation()
  * @uses    PMA_select_language()
  * @uses    PMA_select_server()
- * @uses    PMA_VERSION
  * @uses    file_exists()
  * @uses    sprintf()
  * @uses    count()
@@ -88,7 +147,8 @@ function PMA_auth()
         exit;
     }
 
-    if ($GLOBALS['cfg']['LoginCookieRecall']) {
+    /* No recall if blowfish secret is not configured as it would produce garbage */
+    if ($GLOBALS['cfg']['LoginCookieRecall'] && !empty($GLOBALS['cfg']['blowfish_secret'])) {
         $default_user   = $GLOBALS['PHP_AUTH_USER'];
         $default_server = $GLOBALS['pma_auth_server'];
         $autocomplete   = '';
@@ -106,9 +166,10 @@ function PMA_auth()
     // Defines the "item" image depending on text direction
     $item_img = $GLOBALS['pmaThemeImage'] . 'item_' . $GLOBALS['text_dir'] . '.png';
 
-    /* HTML header */
-    $page_title = 'phpMyAdmin ' . PMA_VERSION;
+    /* HTML header; do not show here the PMA version to improve security */
+    $page_title = 'phpMyAdmin ';
     require './libraries/header_meta_style.inc.php';
+    require './libraries/header_scripts.inc.php';
     ?>
 <script type="text/javascript">
 //<![CDATA[
@@ -123,13 +184,13 @@ if (top != self) {
 <body class="loginform">
 
     <?php
-    if (file_exists('./config.header.inc.php')) {
-          require './config.header.inc.php';
+    if (file_exists(CUSTOM_HEADER_FILE)) {
+        require CUSTOM_HEADER_FILE;
     }
     ?>
 
 <div class="container">
-<a href="http://www.phpmyadmin.net" target="_blank" class="logo"><?php
+<a href="<?php echo PMA_linkURL('http://www.phpmyadmin.net/'); ?>" target="_blank" class="logo"><?php
     $logo_image = $GLOBALS['pmaThemeImage'] . 'logo_right.png';
     if (@file_exists($logo_image)) {
         echo '<img src="' . $logo_image . '" id="imLogo" name="imLogo" alt="phpMyAdmin" border="0" />';
@@ -140,7 +201,7 @@ if (top != self) {
     ?></a>
 <h1>
     <?php
-    echo sprintf($GLOBALS['strWelcome'],
+    echo sprintf(__('Welcome to %s'),
         '<bdo dir="ltr" xml:lang="en">' . $page_title . '</bdo>');
     ?>
 </h1>
@@ -148,42 +209,28 @@ if (top != self) {
 
     // Show error message
     if (! empty($conn_error)) {
-        echo '<div class="error"><h1>' . $GLOBALS['strError'] . '</h1>' . "\n";
-        echo $conn_error . '</div>' . "\n";
+        PMA_Message::rawError($conn_error)->display();
     }
 
     // Displays the languages form
     if (empty($GLOBALS['cfg']['Lang'])) {
         require_once './libraries/display_select_lang.lib.php';
-        PMA_select_language(true);
+        // use fieldset, don't show doc link
+        PMA_select_language(true, false);
     }
 
-    // Displays the warning message and the login form
-    if (empty($GLOBALS['cfg']['blowfish_secret'])) {
-        ?>
-        <div class="error"><h1><?php echo $GLOBALS['strError']; ?></h1>
-            <?php echo $GLOBALS['strSecretRequired']; ?>
-        </div>
-        <?php
-        echo '</div>' . "\n";
-        if (file_exists('./config.footer.inc.php')) {
-            require './config.footer.inc.php';
-        }
-        echo '</body></html>';
-        exit;
-    }
     ?>
 <br />
 <!-- Login form -->
 <form method="post" action="index.php" name="login_form"<?php echo $autocomplete; ?> target="_top" class="login">
     <fieldset>
     <legend>
-<?php 
-    echo $GLOBALS['strLogin']; 
+<?php
+    echo __('Log in');
     echo '<a href="./Documentation.html" target="documentation" ' .
-        'title="' . $GLOBALS['strPmaDocumentation'] . '">';
+        'title="' . __('phpMyAdmin documentation') . '">';
     if ($GLOBALS['cfg']['ReplaceHelpImg']) {
-        echo '<img class="icon" src="' . $GLOBALS['pmaThemeImage'] . 'b_help.png" width="11" height="11" alt="' . $GLOBALS['strPmaDocumentation'] . '" />';
+        echo '<img class="icon" src="' . $GLOBALS['pmaThemeImage'] . 'b_help.png" width="11" height="11" alt="' . __('phpMyAdmin documentation') . '" />';
     } else {
         echo '(*)';
     }
@@ -193,23 +240,23 @@ if (top != self) {
 
 <?php if ($GLOBALS['cfg']['AllowArbitraryServer']) { ?>
         <div class="item">
-            <label for="input_servername"><?php echo $GLOBALS['strLogServer']; ?></label>
-            <input type="text" name="pma_servername" id="input_servername" value="<?php echo htmlspecialchars($default_server); ?>" size="24" class="textfield" />
+            <label for="input_servername" title="<?php echo __('You can enter hostname/IP address and port separated by space.'); ?>"><?php echo __('Server:'); ?></label>
+            <input type="text" name="pma_servername" id="input_servername" value="<?php echo htmlspecialchars($default_server); ?>" size="24" class="textfield" title="<?php echo __('You can enter hostname/IP address and port separated by space.'); ?>" />
         </div>
 <?php } ?>
         <div class="item">
-            <label for="input_username"><?php echo $GLOBALS['strLogUsername']; ?></label>
-            <input type="text" name="pma_username" id="input_username" value="<?php echo htmlspecialchars($default_user); ?>" size="24" class="textfield" />
+            <label for="input_username"><?php echo __('Username:'); ?></label>
+            <input type="text" name="pma_username" id="input_username" value="<?php echo htmlspecialchars($default_user); ?>" size="24" class="textfield"/>
         </div>
         <div class="item">
-            <label for="input_password"><?php echo $GLOBALS['strLogPassword']; ?></label>
+            <label for="input_password"><?php echo __('Password:'); ?></label>
             <input type="password" name="pma_password" id="input_password" value="" size="24" class="textfield" />
         </div>
     <?php
     if (count($GLOBALS['cfg']['Servers']) > 1) {
         ?>
         <div class="item">
-            <label for="select_server"><?php echo $GLOBALS['strServerChoice']; ?>:</label>
+            <label for="select_server"><?php echo __('Server Choice'); ?>:</label>
             <select name="server" id="select_server"
         <?php
         if ($GLOBALS['cfg']['AllowArbitraryServer']) {
@@ -227,82 +274,71 @@ if (top != self) {
     ?>
     </fieldset>
     <fieldset class="tblFooters">
-        <input value="<?php echo $GLOBALS['strGo']; ?>" type="submit" />
-        <input type="hidden" name="lang" value="<?php echo $GLOBALS['lang']; ?>" />
-        <input type="hidden" name="convcharset" value="<?php echo htmlspecialchars($GLOBALS['convcharset'], ENT_QUOTES); ?>" />
+        <input value="<?php echo __('Go'); ?>" type="submit" id="input_go" />
     <?php
-    if (!empty($GLOBALS['target'])) {
-        echo '            <input type="hidden" name="target" value="' . htmlspecialchars($GLOBALS['target']) . '" />' . "\n";
+    $_form_params = array();
+    if (! empty($GLOBALS['target'])) {
+        $_form_params['target'] = $GLOBALS['target'];
     }
-    if (!empty($GLOBALS['db'])) {
-        echo '            <input type="hidden" name="db" value="' . htmlspecialchars($GLOBALS['db']) . '" />' . "\n";
+    if (! empty($GLOBALS['db'])) {
+        $_form_params['db'] = $GLOBALS['db'];
     }
-    if (!empty($GLOBALS['table'])) {
-        echo '            <input type="hidden" name="table" value="' . htmlspecialchars($GLOBALS['table']) . '" />' . "\n";
+    if (! empty($GLOBALS['table'])) {
+        $_form_params['table'] = $GLOBALS['table'];
     }
+    // do not generate a "server" hidden field as we want the "server"
+    // drop-down to have priority
+    echo PMA_generate_common_hidden_inputs($_form_params, '', 0, 'server');
     ?>
     </fieldset>
 </form>
+
     <?php
+
+    // BEGIN Swekey Integration
+    Swekey_login('input_username', 'input_go');
+    // END Swekey Integration
+
     // show the "Cookies required" message only if cookies are disabled
     // (we previously tried to set some cookies)
     if (empty($_COOKIE)) {
-        echo '<div class="notice">' . $GLOBALS['strCookiesRequired'] . '</div>' . "\n";
+        trigger_error(__('Cookies must be enabled past this point.'), E_USER_NOTICE);
     }
-    if (! empty($GLOBALS['PMA_errors']) && is_array($GLOBALS['PMA_errors'])) {
-        foreach ($GLOBALS['PMA_errors'] as $error) {
-            echo '<div class="error">' . $error . '</div>' . "\n";
-        }
-    }
-    // the warning is also displayed on main page but show it also here,
-    // because on some PHP versions running on 64-bit, the blowfish library
-    // does not work and this would prevent login
-    if (defined('PMA_WARN_FOR_MCRYPT')) {
-        echo '<div class="warning">' . PMA_sanitize(sprintf($GLOBALS['strCantLoad'], 'mcrypt')) . '</div>' . "\n";
+    if ($GLOBALS['error_handler']->hasDisplayErrors()) {
+        echo '<div>';
+        $GLOBALS['error_handler']->dispErrors();
+        echo '</div>';
     }
     ?>
 </div>
-<script type="text/javascript">
-// <![CDATA[
-function PMA_focusInput()
-{
-    var input_username = document.getElementById('input_username');
-    var input_password = document.getElementById('input_password');
-    if (input_username.value == '') {
-        input_username.focus();
-    } else {
-        input_password.focus();
+    <?php
+    if (file_exists(CUSTOM_FOOTER_FILE)) {
+        require CUSTOM_FOOTER_FILE;
     }
-}
-
-window.setTimeout('PMA_focusInput()', 500);
-// ]]>
-</script>
+    ?>
 </body>
 </html>
     <?php
-    if (file_exists('./config.footer.inc.php')) {
-         require './config.footer.inc.php';
-    }
     exit;
 } // end of the 'PMA_auth()' function
 
 
+
 /**
  * Gets advanced authentication settings
  *
  * this function DOES NOT check authentication - it just checks/provides
  * authentication credentials required to connect to the MySQL server
- * usally with PMA_DBI_connect()
+ * usually with PMA_DBI_connect()
  *
- * it returns false if there is missing something - which usally leads to
+ * it returns false if something is missing - which usually leads to
  * PMA_auth() which displays login form
  *
- * it returns true if all seems ok which usally leads to PMA_auth_set_user()
+ * it returns true if all seems ok which usually leads to PMA_auth_set_user()
  *
  * it directly switches to PMA_auth_fails() if user inactivity timout is reached
  *
- * @todo    AllowArbitraryServer on does not imply that the user wnats an
+ * @todo    AllowArbitraryServer on does not imply that the user wants an
  *          arbitrary server, or? so we should also check if this is filled and
  *          not only if allowed
  * @uses    $GLOBALS['PHP_AUTH_USER']
@@ -311,7 +347,6 @@ window.setTimeout('PMA_focusInput()', 500);
  * @uses    $GLOBALS['server']
  * @uses    $GLOBALS['from_cookie']
  * @uses    $GLOBALS['pma_auth_server']
- * @uses    $cfg['blowfish_secret']
  * @uses    $cfg['AllowArbitraryServer']
  * @uses    $cfg['LoginCookieValidity']
  * @uses    $cfg['Servers']
@@ -321,7 +356,7 @@ window.setTimeout('PMA_focusInput()', 500);
  * @uses    $_REQUEST['pma_servername'] from login form
  * @uses    $_COOKIE
  * @uses    $_SESSION['last_access_time']
- * @uses    PMA_removeCookie()
+ * @uses    $GLOBALS['PMA_Config']->removeCookie()
  * @uses    PMA_blowfish_decrypt()
  * @uses    PMA_auth_fails()
  * @uses    time()
@@ -341,34 +376,41 @@ function PMA_auth_check()
     $GLOBALS['PHP_AUTH_USER'] = $GLOBALS['PHP_AUTH_PW'] = '';
     $GLOBALS['from_cookie'] = false;
 
-    // avoid an error in mcrypt
-    if (empty($GLOBALS['cfg']['blowfish_secret'])) {
+    // BEGIN Swekey Integration
+    if (! Swekey_auth_check()) {
         return false;
     }
+    // END Swekey Integration
 
     if (defined('PMA_CLEAR_COOKIES')) {
         foreach($GLOBALS['cfg']['Servers'] as $key => $val) {
-            PMA_removeCookie('pmaPass-' . $key);
-            PMA_removeCookie('pmaServer-' . $key);
-            PMA_removeCookie('pmaUser-' . $key);
+            $GLOBALS['PMA_Config']->removeCookie('pmaPass-' . $key);
+            $GLOBALS['PMA_Config']->removeCookie('pmaServer-' . $key);
+            $GLOBALS['PMA_Config']->removeCookie('pmaUser-' . $key);
         }
         return false;
     }
 
     if (! empty($_REQUEST['old_usr'])) {
-        // The user wants to be logged out 
-        // -> delete his choices that were stored in session 
-        session_destroy(); 
+        // The user wants to be logged out
+        // -> delete his choices that were stored in session
+
+        // according to the PHP manual we should do this before the destroy:
+        //$_SESSION = array();
+        // but we still need some parts of the session information
+        // in libraries/header_meta_style.inc.php
+
+        session_destroy();
         // -> delete password cookie(s)
         if ($GLOBALS['cfg']['LoginCookieDeleteAll']) {
             foreach($GLOBALS['cfg']['Servers'] as $key => $val) {
-                PMA_removeCookie('pmaPass-' . $key);
+                $GLOBALS['PMA_Config']->removeCookie('pmaPass-' . $key);
                 if (isset($_COOKIE['pmaPass-' . $key])) {
                     unset($_COOKIE['pmaPass-' . $key]);
                 }
             }
         } else {
-            PMA_removeCookie('pmaPass-' . $GLOBALS['server']);
+            $GLOBALS['PMA_Config']->removeCookie('pmaPass-' . $GLOBALS['server']);
             if (isset($_COOKIE['pmaPass-' . $GLOBALS['server']])) {
                 unset($_COOKIE['pmaPass-' . $GLOBALS['server']]);
             }
@@ -401,7 +443,7 @@ function PMA_auth_check()
 
     $GLOBALS['PHP_AUTH_USER'] = PMA_blowfish_decrypt(
         $_COOKIE['pmaUser-' . $GLOBALS['server']],
-        $GLOBALS['cfg']['blowfish_secret']);
+        PMA_get_blowfish_secret());
 
     // user was never logged in since session start
     if (empty($_SESSION['last_access_time'])) {
@@ -410,6 +452,11 @@ function PMA_auth_check()
 
     // User inactive too long
     if ($_SESSION['last_access_time'] < time() - $GLOBALS['cfg']['LoginCookieValidity']) {
+        PMA_cacheUnset('is_create_db_priv', true);
+        PMA_cacheUnset('is_process_priv', true);
+        PMA_cacheUnset('is_reload_priv', true);
+        PMA_cacheUnset('db_to_create', true);
+        PMA_cacheUnset('dbs_where_create_table_allowed', true);
         $GLOBALS['no_activity'] = true;
         PMA_auth_fails();
         exit;
@@ -422,7 +469,7 @@ function PMA_auth_check()
 
     $GLOBALS['PHP_AUTH_PW'] = PMA_blowfish_decrypt(
         $_COOKIE['pmaPass-' . $GLOBALS['server']],
-        $GLOBALS['cfg']['blowfish_secret'] /* . $_SESSION['last_access_time'] */);
+        PMA_get_blowfish_secret());
 
     if ($GLOBALS['PHP_AUTH_PW'] == "\xff(blank)") {
         $GLOBALS['PHP_AUTH_PW'] = '';
@@ -444,14 +491,13 @@ function PMA_auth_check()
  * @uses    $GLOBALS['pma_auth_server']
  * @uses    $cfg['Server']
  * @uses    $cfg['AllowArbitraryServer']
- * @uses    $cfg['blowfish_secret']
  * @uses    $cfg['LoginCookieStore']
  * @uses    $cfg['PmaAbsoluteUri']
  * @uses    $_SESSION['last_access_time']
  * @uses    PMA_COMING_FROM_COOKIE_LOGIN
- * @uses    PMA_setCookie()
+ * @uses    $GLOBALS['PMA_Config']->setCookie()
  * @uses    PMA_blowfish_encrypt()
- * @uses    PMA_removeCookie()
+ * @uses    $GLOBALS['PMA_Config']->removeCookie()
  * @uses    PMA_sendHeaderLocation()
  * @uses    time()
  * @uses    define()
@@ -480,28 +526,40 @@ function PMA_auth_set_user()
         } // end foreach
     } // end if
 
-    $pma_server_changed = false;
     if ($GLOBALS['cfg']['AllowArbitraryServer']
-     && ! empty($GLOBALS['pma_auth_server'])
-     && $cfg['Server']['host'] != $GLOBALS['pma_auth_server']) {
-        $cfg['Server']['host'] = $GLOBALS['pma_auth_server'];
-        $pma_server_changed = true;
+     && ! empty($GLOBALS['pma_auth_server'])) {
+        /* Allow to specify 'host port' */
+        $parts = explode(' ', $GLOBALS['pma_auth_server']);
+        if (count($parts) == 2) {
+            $tmp_host = $parts[0];
+            $tmp_port = $parts[1];
+        } else {
+            $tmp_host = $GLOBALS['pma_auth_server'];
+            $tmp_port = '';
+        }
+        if ($cfg['Server']['host'] != $GLOBALS['pma_auth_server']) {
+            $cfg['Server']['host'] = $tmp_host;
+            if (!empty($tmp_port)) {
+                $cfg['Server']['port'] = $tmp_port;
+            }
+        }
+        unset($tmp_host, $tmp_port, $parts);
     }
     $cfg['Server']['user']     = $GLOBALS['PHP_AUTH_USER'];
     $cfg['Server']['password'] = $GLOBALS['PHP_AUTH_PW'];
 
     $_SESSION['last_access_time'] = time();
 
-    // Name and password cookies needs to be refreshed each time
+    // Name and password cookies need to be refreshed each time
     // Duration = one month for username
-    PMA_setCookie('pmaUser-' . $GLOBALS['server'],
+    $GLOBALS['PMA_Config']->setCookie('pmaUser-' . $GLOBALS['server'],
         PMA_blowfish_encrypt($cfg['Server']['user'],
-            $GLOBALS['cfg']['blowfish_secret']));
+            PMA_get_blowfish_secret()));
 
     // Duration = as configured
-    PMA_setCookie('pmaPass-' . $GLOBALS['server'],
+    $GLOBALS['PMA_Config']->setCookie('pmaPass-' . $GLOBALS['server'],
         PMA_blowfish_encrypt(!empty($cfg['Server']['password']) ? $cfg['Server']['password'] : "\xff(blank)",
-            $GLOBALS['cfg']['blowfish_secret'] /* . $_SESSION['last_access_time'] */),
+            PMA_get_blowfish_secret()),
         null,
         $GLOBALS['cfg']['LoginCookieStore']);
 
@@ -510,11 +568,11 @@ function PMA_auth_set_user()
     if (! $GLOBALS['from_cookie']) {
         if ($GLOBALS['cfg']['AllowArbitraryServer']) {
             if (! empty($GLOBALS['pma_auth_server'])) {
-                // Duration = one month for serverrname
-                PMA_setCookie('pmaServer-' . $GLOBALS['server'], $cfg['Server']['host']);
+                // Duration = one month for servername
+                $GLOBALS['PMA_Config']->setCookie('pmaServer-' . $GLOBALS['server'], $cfg['Server']['host']);
             } else {
                 // Delete servername cookie
-                PMA_removeCookie('pmaServer-' . $GLOBALS['server']);
+                $GLOBALS['PMA_Config']->removeCookie('pmaServer-' . $GLOBALS['server']);
             }
         }
 
@@ -529,10 +587,6 @@ function PMA_auth_set_user()
         if (strlen($GLOBALS['table'])) {
             $url_params['table'] = $GLOBALS['table'];
         }
-        // Language change from the login panel needs to be remembered
-        if (! empty($GLOBALS['lang'])) {
-            $url_params['lang'] = $GLOBALS['lang'];
-        }
         // any target to pass?
         if (! empty($GLOBALS['target']) && $GLOBALS['target'] != 'index.php') {
             $url_params['target'] = $GLOBALS['target'];
@@ -542,6 +596,12 @@ function PMA_auth_set_user()
          * whether we come from a fresh cookie login
          */
         define('PMA_COMING_FROM_COOKIE_LOGIN', true);
+
+        /**
+         * Clear user cache.
+         */
+        PMA_clearUserCache();
+
         PMA_sendHeaderLocation($redirect_url . PMA_generate_common_url($url_params, '&'));
         exit();
     } // end if
@@ -559,15 +619,11 @@ function PMA_auth_set_user()
  * this function MUST exit/quit the application,
  * currently doen by call to PMA_auth()
  *
- * @todo    $php_errormsg is invalid here!? it will never be set in this scope
  * @uses    $GLOBALS['server']
  * @uses    $GLOBALS['allowDeny_forbidden']
- * @uses    $GLOBALS['strAccessDenied']
- * @uses    $GLOBALS['strNoActivity']
- * @uses    $GLOBALS['strCannotLogin']
  * @uses    $GLOBALS['no_activity']
  * @uses    $cfg['LoginCookieValidity']
- * @uses    PMA_removeCookie()
+ * @uses    $GLOBALS['PMA_Config']->removeCookie()
  * @uses    PMA_getenv()
  * @uses    PMA_DBI_getError()
  * @uses    PMA_sanitize()
@@ -581,12 +637,14 @@ function PMA_auth_fails()
     global $conn_error;
 
     // Deletes password cookie and displays the login form
-    PMA_removeCookie('pmaPass-' . $GLOBALS['server']);
+    $GLOBALS['PMA_Config']->removeCookie('pmaPass-' . $GLOBALS['server']);
 
-    if (! empty($GLOBALS['allowDeny_forbidden'])) {
-        $conn_error = $GLOBALS['strAccessDenied'];
+    if (! empty($GLOBALS['login_without_password_is_forbidden'])) {
+        $conn_error = __('Login without a password is forbidden by configuration (see AllowNoPassword)');
+    } elseif (! empty($GLOBALS['allowDeny_forbidden'])) {
+        $conn_error = __('Access denied');
     } elseif (! empty($GLOBALS['no_activity'])) {
-        $conn_error = sprintf($GLOBALS['strNoActivity'], $GLOBALS['cfg']['LoginCookieValidity']);
+        $conn_error = sprintf(__('No activity within %s seconds; please log in again'), $GLOBALS['cfg']['LoginCookieValidity']);
         // Remember where we got timeout to return on same place
         if (PMA_getenv('SCRIPT_NAME')) {
             $GLOBALS['target'] = basename(PMA_getenv('SCRIPT_NAME'));
@@ -596,13 +654,15 @@ function PMA_auth_fails()
             }
         }
     } elseif (PMA_DBI_getError()) {
-        $conn_error = PMA_sanitize(PMA_DBI_getError());
-    } elseif (isset($php_errormsg)) {
-        $conn_error = $php_errormsg;
+        $conn_error = '#' . $GLOBALS['errno'] . ' ' . __('Cannot log in to the MySQL server');
     } else {
-        $conn_error = $GLOBALS['strCannotLogin'];
+        $conn_error = __('Cannot log in to the MySQL server');
     }
 
+    // needed for PHP-CGI (not need for FastCGI or mod-php)
+    header('Cache-Control: no-store, no-cache, must-revalidate');
+    header('Pragma: no-cache');
+
     PMA_auth();
 } // end of the 'PMA_auth_fails()' function
 
