@@ -571,11 +571,11 @@ function PMA_insertIntoTargetTable($matching_table, $src_db, $trg_db, $src_link,
                     }             
                     $insert_query .= ") VALUES(";
                     if (sizeof($table_fields[$matching_table_index]) == 1) {
-                         $insert_query .= "'" . $result[0] . "'";
+                         $insert_query .= "'" . PMA_sqlAddslashes($result[0]) . "'";
                     } else {
                         for ($field_index = 0; $field_index < sizeof($table_fields[$matching_table_index]); $field_index++) {
                             if (isset($result[0][$table_fields[$matching_table_index][$field_index]])) {
-                                $insert_query .= "'" . $result[0][$table_fields[$matching_table_index][$field_index]] . "'";
+                                $insert_query .= "'" . PMA_sqlAddslashes($result[0][$table_fields[$matching_table_index][$field_index]]) . "'";
                             } else {
                                 $insert_query .= "'NULL'";
                             }
@@ -624,7 +624,7 @@ function PMA_createTargetTables($src_db, $trg_db, $src_link, $trg_link, &$uncomm
         $Create_Query = PMA_DBI_fetch_value("SHOW CREATE TABLE " . PMA_backquote($src_db) . '.' . PMA_backquote($uncommon_tables[$table_index]), 0, 1, $src_link);
 
         // Replace the src table name with a `dbname`.`tablename`
-        $Create_Table_Query = preg_replace('/' . preg_quote(PMA_backquote($uncommon_tables[$table_index]), '/') . '/', 
+        $Create_Table_Query = preg_replace('/' . PMA_backquote($uncommon_tables[$table_index]) . '/', 
                                             PMA_backquote($trg_db) . '.' .PMA_backquote($uncommon_tables[$table_index]),
                                             $Create_Query,
                                             $limit = 1
@@ -1324,10 +1324,6 @@ function PMA_displayQuery($query) {
 
 /**
  * PMA_syncDisplayHeaderSource() shows the header for source database 
- * @uses   $GLOBALS['strDatabase_src'] 
- * @uses   $GLOBALS['strDifference'] 
- * @uses   $GLOBALS['strCurrentServer'] 
- * @uses   $GLOBALS['strRemoteServer'] 
  * @uses   $_SESSION['src_type'] 
  * @uses   $_SESSION['src_server']['host'] 
  *
@@ -1338,22 +1334,19 @@ function PMA_syncDisplayHeaderSource($src_db) {
 
     echo '<table id="serverstatusconnections" class="data" width="55%">';
     echo '<tr>';
-    echo '<th>' . $GLOBALS['strDatabase_src'] . ':  ' . $src_db . '<br />(';
+    echo '<th>' . __('Source database') . ':  ' . $src_db . '<br />(';
     if ('cur' == $_SESSION['src_type']) {
-        echo $GLOBALS['strCurrentServer'];
+        echo __('Current server');
     } else {
-        echo $GLOBALS['strRemoteServer'] . ' ' . $_SESSION['src_server']['host'];
+        echo __('Remote server') . ' ' . $_SESSION['src_server']['host'];
     }
     echo ')</th>';
-    echo '<th>' . $GLOBALS['strDifference'] . '</th>';
+    echo '<th>' . __('Difference') . '</th>';
     echo '</tr>';
 }
 
 /**
  * PMA_syncDisplayHeaderTargetAndMatchingTables() shows the header for target database and the matching tables
- * @uses   $GLOBALS['strDatabase_trg'] 
- * @uses   $GLOBALS['strCurrentServer'] 
- * @uses   $GLOBALS['strRemoteServer'] 
  * @uses   $_SESSION['trg_type'] 
  * @uses   $_SESSION['trg_server']['host'] 
  * 
@@ -1364,11 +1357,11 @@ function PMA_syncDisplayHeaderSource($src_db) {
 function PMA_syncDisplayHeaderTargetAndMatchingTables($trg_db, $matching_tables) {
     echo '<table id="serverstatusconnections" class="data" width="43%">';
     echo '<tr>';
-    echo '<th>' . $GLOBALS['strDatabase_trg'] . ':  '. $trg_db . '<br />(';
+    echo '<th>' . __('Target database') . ':  '. $trg_db . '<br />(';
     if ('cur' == $_SESSION['trg_type']) {
-        echo $GLOBALS['strCurrentServer'];
+        echo __('Current server');
     } else {
-        echo $GLOBALS['strRemoteServer'] . ' ' . $_SESSION['trg_server']['host'];
+        echo __('Remote server') . ' ' . $_SESSION['trg_server']['host'];
     }
     echo ')</th>';
     echo '</tr>';
